@@ -197,6 +197,9 @@ const translationMap = {
                 en: 'How to generate',
                 zh: '如何生成'
             },
+            windowsAndMacOsXSpecificOptions: {
+                en: 'Windows And Mac Os X Specific Options',
+            },
             windowsSpecificOptions: {
                 en: 'Windows specific options',
                 zh: 'Windows特定选项'
@@ -232,6 +235,10 @@ const translationMap = {
                 en: 'Enable',
                 zh: '开启'
             },
+            disable: {
+                en: 'Disable',
+                zh: '关掉'
+            },
             converting: {
                 en: 'Converting...',
                 zh: '转换中······'
